@@ -1032,7 +1032,7 @@ static int CGNSfile (ClientData data, Tcl_Interp *interp,
         return (get_error (interp, "cgio_check_file"));
     if (file_type == CGIO_FILE_ADF)
         Tcl_SetResult (interp, "adf", TCL_STATIC);
-    else if (file_type == CGIO_FILE_HDF5 || file_type == CGIO_FILE_PHDF5)
+    else if (file_type == CGIO_FILE_HDF5)
         Tcl_SetResult (interp, "hdf5", TCL_STATIC);
     else {
         Tcl_SetResult (interp, "unknown file type", TCL_STATIC);
@@ -1459,7 +1459,7 @@ static int CGIOtype (ClientData data, Tcl_Interp *interp,
                     Tcl_AppendResult (interp, "malloc failed for data", NULL);
                     return TCL_ERROR;
                 }
-                if (cgio_read_all_data (cgioNum, node_id, olddata)) {
+                if (cgio_read_all_data_type (cgioNum, node_id, dtold->name, olddata)) {
                     free (olddata);
                     return (get_error (interp, "cgio_read_all_data"));
                 }
@@ -1653,9 +1653,9 @@ static int CGIOread (ClientData data, Tcl_Interp *interp,
         return TCL_ERROR;
     }
 
-    if (cgio_read_all_data (cgioNum, node_id, values)) {
+    if (cgio_read_all_data_type (cgioNum, node_id, dt->name, values)) {
         free (values);
-        return (get_error (interp, "cgio_read_all_data"));
+        return (get_error (interp, "cgio_read_all_data_type"));
     }
 
     if (dt->type == C1data) {
