@@ -1,14 +1,13 @@
 #ifndef _TK_OGL
 #define _TK_OGL
 
-#include <tk.h>
 #if defined(__WIN32__) || defined(_WIN32)
 #   define WIN32_LEAN_AND_MEAN
 #   include <windows.h>
 #   undef WIN32_LEAN_AND_MEAN
 #endif
-#include <GL/gl.h>
-#include <GL/glu.h>
+#include <tk.h>
+#include "gl_config.h"
 #include <assert.h>
 #if defined(__WIN32__) || defined(_WIN32)
 #   include "tkWinInt.h"
@@ -23,9 +22,10 @@
 #	        define EXPORT(a,b) a b
 #	    endif
 #   endif
+#elif defined(__APPLE__)
+#include <X11/Xatom.h>
 #else
 #   define EXPORT(a,b) a b
-#   include <GL/glx.h>
 #   include <X11/Xatom.h>		/* for XA_RGB_DEFAULT_MAP atom */
 #   include <X11/Xmu/StdCmap.h>	/* for XmuLookupStandardColormap() */
 #endif
