@@ -25,6 +25,7 @@ int main(int argc, char* argv[]) {
 	MPI_Info info;
         MPI_Comm comm_self = MPI_COMM_SELF;
 	int fn;
+        size_t value[2];
 
 	err = MPI_Init(&argc,&argv);
 	if(err!=MPI_SUCCESS) cgp_doError;
@@ -97,9 +98,41 @@ int main(int argc, char* argv[]) {
            if (cgp_close(fn))
                cg_error_exit();
         }
+        MPI_Barrier(MPI_COMM_WORLD);
 
         cgp_mpi_comm(MPI_COMM_WORLD);
 
+        value[0] = 0; /* threshold for H5Pset_alignment */
+        value[1] = 2*1024*1024; /* alignment for H5Pset_alignment */
+
+        if (cg_configure(CG_CONFIG_HDF5_ALIGNMENT, value))
+            cgp_error_exit();
+
+        if (cg_configure(CG_CONFIG_HDF5_MD_BLOCK_SIZE, (void *)(8*1024)))
+            cgp_error_exit();
+
+        if (cg_configure(CG_CONFIG_HDF5_BUFFER, (void *)(4*1024*1024)))
+            cgp_error_exit();
+
+        if (cg_configure(CG_CONFIG_HDF5_SIEVE_BUF_SIZE, (void *)(2*1024*1024)))
+            cgp_error_exit();
+
+        if (cg_configure(CG_CONFIG_HDF5_ELINK_CACHE_SIZE, (void *)(10)))
+            cgp_error_exit();
+
+        if (cgp_open("test_cg_conf.cgns", CG_MODE_WRITE, &fn))
+          cgp_error_exit();
+        if (cgp_close(fn))
+          cgp_error_exit();
+
+        if (cg_configure(CG_CONFIG_RESET, (void *)CG_CONFIG_RESET_HDF5))
+            cgp_error_exit();
+
+        if (cgp_open("test_cg_conf.cgns", CG_MODE_WRITE, &fn))
+          cgp_error_exit();
+        if (cgp_close(fn))
+          cgp_error_exit();
+
 	err = MPI_Finalize();
 	if(err!=MPI_SUCCESS) cgp_doError;
 	return err;
