@@ -5,21 +5,29 @@
 int main (int argc, char **argv)
 {
     double start, finish;
-    int cgfile, mode = CG_MODE_READ;
+    int cgfile, mode = CG_MODE_WRITE;
+    const char *filename = "very_long_filename_to_test_buffer_overflow_handling_that_could_potentially_cause_issues_in_string_operation_and_memory_management.cgns";
 
-    if (argc < 2 || argc > 3) {
+    if (argc > 3) {
         fprintf (stderr, "open_cgns [-m] CGNSfile\n");
         exit (1);
     }
     if (argc > 2) {
         mode = CG_MODE_MODIFY;
-        cg_configure (CG_CONFIG_COMPRESS, (void *)1);
+#if 0
+        if (cg_configure (CG_CONFIG_COMPRESS, (void *)1))
+          cg_error_exit();
+#endif
+        filename = argv[2];
+    }
+    else if (argc == 2) {
+      filename = argv[1];
     }
 
-    printf ("opening cgns file <%s> ...", argv[argc-1]);
+    printf ("opening cgns file <%s> ...", filename);
     fflush (stdout);
     start = elapsed_time ();
-    if (cg_open (argv[argc-1], mode, &cgfile)) cg_error_exit();
+    if (cg_open (filename, mode, &cgfile)) cg_error_exit();
     finish = elapsed_time ();
     printf (" %g secs\n", finish - start);
 
