@@ -106,11 +106,11 @@ int main (int argc, char *argv[])
         exit(1);
     }
 
-    // 2d reshape b
+    /* 2d reshape b */
     float (*fvalues_2d)[dims_2d(0)]  = (float (*)[dims_2d(0)])fvalues_1d;
     double (*dvalues_2d)[dims_2d(0)] = (double (*)[dims_2d(0)])dvalues_1d;
 
-    // 3d reshape
+    /* 3d reshape */
     float (*fvalues_3d)[dims_3d(1)][dims_3d(0)] =
       (float (*)[dims_3d(1)][dims_3d(0)])fvalues_1d;
     float (*fbuf_3d)[dims_3d(1)][dims_3d(0)] =
@@ -125,8 +125,8 @@ int main (int argc, char *argv[])
         for (j = 0; j < dims_3d(1); j++) {
             for (i = 0; i < dims_3d(0); i++) {
                 compute_values(i, j, k, 0);
-                assert(fvalues_3d[k][j][i] = fvalues_1d[idx3d_1d(i,j,k)]);
-                assert(dvalues_3d[k][j][i] = dvalues_1d[idx3d_1d(i,j,k)]);
+                assert(fvalues_3d[k][j][i] == fvalues_1d[idx3d_1d(i,j,k)]);
+                assert(dvalues_3d[k][j][i] == dvalues_1d[idx3d_1d(i,j,k)]);
                 n = idx3d_1d(i, j, k);
                 idx1d_3d(n, &ii, &jj, &kk);
                 assert(i == ii && j == jj && k == kk);
@@ -135,8 +135,8 @@ int main (int argc, char *argv[])
     }
     for (j = 0; j < dims_2d(1); j++)
       for (i = 0; i < dims_2d(0); i++) {
-          assert(fvalues_2d[j][i] = fvalues_1d[idx2d_1d(i,j)]);
-          assert(dvalues_2d[j][i] = dvalues_1d[idx2d_1d(i,j)]);
+          assert(fvalues_2d[j][i] == fvalues_1d[idx2d_1d(i,j)]);
+          assert(dvalues_2d[j][i] == dvalues_1d[idx2d_1d(i,j)]);
       }
 
     /* open */
@@ -256,7 +256,8 @@ int main (int argc, char *argv[])
                               3, m_dims, m_rmin, m_rmax, ibuf_1d))
         cg_error_exit();
     for (i = 0; i < dims_1d(0); i++) {
-        if (ibuf_1d[i] != (int)fvalues_1d[i]) ++np;
+        int tmp_cmp = (int)round(fvalues_1d[i]);
+        if (ibuf_1d[i] != tmp_cmp) ++np;
     }
     nn += np;
     if (np) printf("%d differences in values (T2)\n", np);
@@ -463,7 +464,8 @@ int main (int argc, char *argv[])
                               1, m_dims, m_rmin, m_rmax, ibuf_1d))
       cg_error_exit();
     for (i = 0; i < dims_1d(0); i++) {
-        if (ibuf_1d[i] != (int)fvalues_1d[i]) ++np;
+        int tmp_cmp = (int)round(fvalues_1d[i]);
+        if (ibuf_1d[i] != tmp_cmp) ++np;
     }
     /* read the second in 3d */
     for (n=0; n<3; n++) {
@@ -482,7 +484,8 @@ int main (int argc, char *argv[])
                               3, m_dims, m_rmin, m_rmax, ibuf_1d))
       cg_error_exit();
     for (i = 0; i < dims_1d(0); i++) {
-        if (ibuf_1d[i] != (int)dvalues_1d[i]) ++np;
+        int tmp_cmp = (int)lround(dvalues_1d[i]);
+        if (ibuf_1d[i] != tmp_cmp) ++np;
     }
     nn += np;
     if (np) printf("%d differences in values (T5)\n", np);
